@@ -51,8 +51,8 @@ class ComicCreator : public QObject, public ThumbCreator
     Q_OBJECT
     public:
         ComicCreator();
-        virtual bool create(const QString& path, int width, int height, QImage& img);
-        virtual Flags flags() const;
+        bool create(const QString& path, int width, int height, QImage& img) override;
+        Flags flags() const override;
 
     private:
         enum Type {
